package com.slugwars;

import com.badlogic.gdx.Game;
import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.GlyphLayout;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.InputListener;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;

public class MenuScreen extends BaseScreen
{
    private Stage stage;
    private Skin skin;
    private static final String str = "SLUG WAR";
    private BitmapFont font;
    private Texture title = new Texture("titulo_bonito.png");
    private GlyphLayout layout;

    public MenuScreen(MainGame game) {
        super(game);
        skin = new Skin(Gdx.files.internal("glassy-ui.json"));
    }

    @Override
    public void show() {
        stage = new Stage();
        Table table = new Table();
        table.setFillParent(true);
        table.center();


        font = new BitmapFont();
        font.getData().setScale(10f,10f);

        Gdx.input.setInputProcessor(stage);


        TextButton play = new TextButton("Jugar", skin);
        TextButton exit = new TextButton("Salir", skin);
        TextButton instruction = new TextButton("Instrucciones", skin);

        instruction.addListener(new InputListener(){
            @Override
            public boolean touchDown(InputEvent event, float x, float y, int pointer, int button) {
                ((Game)Gdx.app.getApplicationListener()).setScreen(new InstructionScreen(game));
                return true;
            }
        });
        play.addListener(new InputListener(){
            @Override
            public boolean touchDown(InputEvent event, float x, float y, int pointer, int button) {
                ((Game)Gdx.app.getApplicationListener()).setScreen(new PlayerScreen(game));
                return true;
            }
        });
        exit.addListener(new InputListener(){
            @Override
            public boolean touchDown(InputEvent event, float x, float y, int pointer, int button) {
                Gdx.app.exit();
                System.exit(0);
                return true;
            }
        });
        table.add(play);
        table.row();
        table.add(instruction);
        table.row();
        table.add(exit);
        table.row();

        stage.addActor(table);

        for(HexActor actor : game.actors){
            actor.setPlayer(0);
            actor.offSelect();
            actor.setTexture(game.hexture0);
        }
        game.p1.decScore(game.p1.getScore());
        game.p2.decScore(game.p2.getScore());
    }

    @Override
    public void render(float delta) {
        Gdx.gl.glClearColor(1f,1f, 1f, 1f);
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);
        game.batch.begin();
        game.batch.draw(title, (float)(Gdx.graphics.getWidth()/2 - title.getWidth()/2),(float)(Gdx.graphics.getHeight() - title.getHeight()));
        game.batch.end();
        stage.act();
        game.batch.begin();
        stage.draw();
        game.batch.end();
    }

    @Override
    public void hide() {
        stage.dispose();
    }

    @Override
    public void dispose() {
        skin.dispose();
    }
}